@@ -24,7 +24,6 @@ from typing import (
 )
 
 from ....jsonrpc2.protocol import rpc_method
-from ....utils.async_cache import AsyncSimpleLRUCache
 from ....utils.async_tools import (
     Lock,
     async_event,
@@ -162,7 +161,6 @@ class Workspace(LanguageServerProtocolPart, HasExtendCapabilities):
         self._file_watchers_lock = Lock()
 
         self.parent.on_shutdown.add(self._on_shutdown)
-        self._config_cache = AsyncSimpleLRUCache(max_items=1000)
 
     @property
     def workspace_folders(self) -> List[WorkspaceFolder]:
@@ -239,7 +237,6 @@ class Workspace(LanguageServerProtocolPart, HasExtendCapabilities):
     @rpc_method(name="workspace/didChangeConfiguration", param_type=DidChangeConfigurationParams)
     @_logger.call
     async def _workspace_did_change_configuration(self, settings: Dict[str, Any], *args: Any, **kwargs: Any) -> None:
-        await self._config_cache.clear()
         self.settings = settings
         await self.did_change_configuration(self, settings)
 
@@ -315,10 +312,6 @@ class Workspace(LanguageServerProtocolPart, HasExtendCapabilities):
         await self.did_delete_files(self, list(f.uri for f in files))
 
     async def get_configuration(self, section: Type[_TConfig], scope_uri: Union[str, Uri, None] = None) -> _TConfig:
-        return await self._config_cache.get(self._get_configuration, section, scope_uri)
-
-    async def _get_configuration(self, section: Type[_TConfig], scope_uri: Union[str, Uri, None] = None) -> _TConfig:
-
         config = await self.get_configuration_raw(
             section=cast(HasConfigSection, section).__config_section__, scope_uri=scope_uri
         )
@@ -328,6 +321,7 @@ class Workspace(LanguageServerProtocolPart, HasExtendCapabilities):
     async def get_configuration_raw(
         self, section: Optional[str], scope_uri: Union[str, Uri, None] = None
     ) -> Optional[Any]:
+
         if (
             self.parent.client_capabilities
             and self.parent.client_capabilities.workspace
