@@ -30,6 +30,7 @@ from ..utils.ast_utils import (
     range_from_node,
     range_from_node_or_token,
     range_from_token,
+    strip_variable_token,
     tokenize_variables,
 )
 from ..utils.async_ast import AsyncVisitor
@@ -100,6 +101,46 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
         else:
             yield token
 
+    async def visit_Variable(self, node: ast.AST) -> None:  # noqa: N802
+        from robot.parsing.lexer.tokens import Token as RobotToken
+        from robot.parsing.model.statements import Variable
+        from robot.variables import search_variable
+
+        variable = cast(Variable, node)
+
+        name_token = variable.get_token(RobotToken.VARIABLE)
+        name = name_token.value
+
+        if name is not None:
+
+            match = search_variable(name, ignore_errors=True)
+            if not match.is_assign(allow_assign_mark=True):
+                return
+
+            if name.endswith("="):
+                name = name[:-1].rstrip()
+
+            r = range_from_token(
+                strip_variable_token(
+                    RobotToken(name_token.type, name, name_token.lineno, name_token.col_offset, name_token.error)
+                )
+            )
+
+            var_def = next(
+                (
+                    v
+                    for v in await self.namespace.get_own_variables()
+                    if v.name_token is not None and range_from_token(v.name_token) == r
+                ),
+                None,
+            )
+
+            if var_def is None:
+                return
+
+            if var_def not in self._variable_references:
+                self._variable_references[var_def] = set()
+
     async def visit(self, node: ast.AST) -> None:
         from robot.parsing.lexer.tokens import Token as RobotToken
         from robot.parsing.model.statements import (
@@ -108,6 +149,7 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
             KeywordCall,
             Template,
             TestTemplate,
+            Variable,
         )
         from robot.variables.search import contains_variable
 
@@ -118,7 +160,7 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
             )
 
             if isinstance(node, Statement) and isinstance(node, KeywordCall) and node.keyword:
-                kw_doc = await self.namespace.find_keyword(node.keyword)
+                kw_doc = await self.finder.find_keyword(node.keyword)
                 if kw_doc is not None and kw_doc.longname in ["BuiltIn.Comment"]:
                     severity = DiagnosticSeverity.HINT
 
@@ -126,7 +168,9 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                 for token1 in (
                     t
                     for t in node.tokens
-                    if t.type != RobotToken.VARIABLE and t.error is None and contains_variable(t.value, "$@&%")
+                    if not (isinstance(node, Variable) and t.type == RobotToken.VARIABLE)
+                    and t.error is None
+                    and contains_variable(t.value, "$@&%")
                 ):
                     async for token in self.yield_argument_name_and_rest(node, token1):
                         if isinstance(node, Arguments) and token.value == "@{}":
@@ -146,6 +190,7 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                                     message=f"Variable '{var.name}' not found.",
                                     severity=severity,
                                     source=DIAGNOSTICS_SOURCE_NAME,
+                                    code="VariableNotFound",
                                 )
                             else:
                                 if self.namespace.document is not None:
@@ -154,6 +199,13 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                                         self._variable_references[var].add(
                                             Location(self.namespace.document.document_uri, var_range)
                                         )
+                                    elif var not in self._variable_references and token1.type in [
+                                        RobotToken.ASSIGN,
+                                        RobotToken.ARGUMENT,
+                                        RobotToken.VARIABLE,
+                                    ]:
+                                        self._variable_references[var] = set()
+
             if (
                 isinstance(node, Statement)
                 and isinstance(node, self.get_expression_statement_types())
@@ -173,6 +225,7 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                             message=f"Variable '{var.name}' not found.",
                             severity=DiagnosticSeverity.ERROR,
                             source=DIAGNOSTICS_SOURCE_NAME,
+                            code="VariableNotFound",
                         )
                     else:
                         if self.namespace.document is not None:
@@ -221,7 +274,17 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
             return
 
         self._diagnostics.append(
-            Diagnostic(range, message, severity, code, code_description, source, tags, related_information, data)
+            Diagnostic(
+                range,
+                message,
+                severity,
+                code,
+                code_description,
+                source or DIAGNOSTICS_SOURCE_NAME,
+                tags,
+                related_information,
+                data,
+            )
         )
 
     async def _analyze_keyword_call(
@@ -243,7 +306,7 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
             if not allow_variables and not is_not_variable_token(keyword_token):
                 return None
 
-            keyword_token = self.strip_bdd_prefix(keyword_token)
+            keyword_token = self.strip_bdd_prefix(self.namespace, keyword_token)
             kw_range = range_from_token(keyword_token)
 
             if keyword is not None:
@@ -271,7 +334,6 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                     range=kw_range,
                     message=e.message,
                     severity=e.severity,
-                    source=DIAGNOSTICS_SOURCE_NAME,
                     code=e.code,
                 )
 
@@ -284,7 +346,6 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                         range=kw_range,
                         message="Keyword definition contains errors.",
                         severity=DiagnosticSeverity.ERROR,
-                        source=DIAGNOSTICS_SOURCE_NAME,
                         related_information=[
                             DiagnosticRelatedInformation(
                                 location=Location(
@@ -328,22 +389,22 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                         message=f"Keyword '{result.name}' is deprecated"
                         f"{f': {result.deprecated_message}' if result.deprecated_message else ''}.",
                         severity=DiagnosticSeverity.HINT,
-                        source=DIAGNOSTICS_SOURCE_NAME,
                         tags=[DiagnosticTag.Deprecated],
+                        code="DeprecatedKeyword",
                     )
                 if result.is_error_handler:
                     await self.append_diagnostics(
                         range=kw_range,
                         message=f"Keyword definition contains errors: {result.error_handler_message}",
                         severity=DiagnosticSeverity.ERROR,
-                        source=DIAGNOSTICS_SOURCE_NAME,
+                        code="KeywordContainsErrors",
                     )
                 if result.is_reserved():
                     await self.append_diagnostics(
                         range=kw_range,
                         message=f"'{result.name}' is a reserved keyword.",
                         severity=DiagnosticSeverity.ERROR,
-                        source=DIAGNOSTICS_SOURCE_NAME,
+                        code="ReservedKeyword",
                     )
 
                 if not isinstance(node, (Template, TestTemplate)):
@@ -365,7 +426,6 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                             ),
                             message=str(e),
                             severity=DiagnosticSeverity.ERROR,
-                            source=DIAGNOSTICS_SOURCE_NAME,
                             code=type(e).__qualname__,
                         )
 
@@ -376,7 +436,6 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                 range=range_from_node_or_token(node, keyword_token),
                 message=str(e),
                 severity=DiagnosticSeverity.ERROR,
-                source=DIAGNOSTICS_SOURCE_NAME,
                 code=type(e).__qualname__,
             )
 
@@ -409,7 +468,7 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                                 range=range_from_token(var_token),
                                 message=f"Variable '{var.name}' not found.",
                                 severity=DiagnosticSeverity.ERROR,
-                                source=DIAGNOSTICS_SOURCE_NAME,
+                                code="VariableNotFound",
                             )
                         else:
                             if self.namespace.document is not None:
@@ -472,7 +531,7 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                         range=range_from_token(t),
                         message=f"Incorrect use of {t.value}.",
                         severity=DiagnosticSeverity.ERROR,
-                        source=DIAGNOSTICS_SOURCE_NAME,
+                        code="IncorrectUse",
                     )
                     continue
 
@@ -630,7 +689,6 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                 range=range_from_node_or_token(value, value.get_token(RobotToken.ASSIGN)),
                 message="Keyword name cannot be empty.",
                 severity=DiagnosticSeverity.ERROR,
-                source=DIAGNOSTICS_SOURCE_NAME,
                 code="KeywordError",
             )
         else:
@@ -643,8 +701,8 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                 range=range_from_node_or_token(value, value.get_token(RobotToken.ASSIGN)),
                 message="Code is unreachable.",
                 severity=DiagnosticSeverity.HINT,
-                source=DIAGNOSTICS_SOURCE_NAME,
                 tags=[DiagnosticTag.Unnecessary],
+                code="CodeUnreachable",
             )
 
         await self.generic_visit(node)
@@ -662,7 +720,6 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                 range=range_from_node_or_token(testcase, name_token),
                 message="Test case name cannot be empty.",
                 severity=DiagnosticSeverity.ERROR,
-                source=DIAGNOSTICS_SOURCE_NAME,
                 code="KeywordError",
             )
 
@@ -694,7 +751,6 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                     range=range_from_node_or_token(keyword, name_token),
                     message="Keyword cannot have both normal and embedded arguments.",
                     severity=DiagnosticSeverity.ERROR,
-                    source=DIAGNOSTICS_SOURCE_NAME,
                     code="KeywordError",
                 )
         else:
@@ -703,7 +759,6 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                 range=range_from_node_or_token(keyword, name_token),
                 message="Keyword name cannot be empty.",
                 severity=DiagnosticSeverity.ERROR,
-                source=DIAGNOSTICS_SOURCE_NAME,
                 code="KeywordError",
             )
 
@@ -756,7 +811,6 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                         range=range_from_node(arguments, skip_non_data=True),
                         message=str(e),
                         severity=DiagnosticSeverity.ERROR,
-                        source=DIAGNOSTICS_SOURCE_NAME,
                         code=type(e).__qualname__,
                     )
 
@@ -765,7 +819,6 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                     range=range_from_node(arguments, skip_non_data=True),
                     message=d.message,
                     severity=d.severity,
-                    source=DIAGNOSTICS_SOURCE_NAME,
                     code=d.code,
                 )
 
