@@ -41,6 +41,7 @@ from ...common.lsp_types import (
     Range,
 )
 from ...common.text_document import TextDocument
+from ..languages import Languages
 from ..utils.ast_utils import (
     Token,
     range_from_node,
@@ -51,6 +52,7 @@ from ..utils.ast_utils import (
 from ..utils.async_ast import AsyncVisitor
 from ..utils.match import eq
 from ..utils.variables import BUILTIN_VARIABLES
+from ..utils.version import get_robot_version
 from .entities import (
     ArgumentDefinition,
     BuiltInVariableDefinition,
@@ -547,6 +549,7 @@ class Namespace:
         invalidated_callback: Callable[[Namespace], None],
         document: Optional[TextDocument] = None,
         document_type: Optional[DocumentType] = None,
+        languages: Optional[Languages] = None,
     ) -> None:
         super().__init__()
 
@@ -557,6 +560,7 @@ class Namespace:
         self.invalidated_callback = invalidated_callback
         self._document = weakref.ref(document) if document is not None else None
         self.document_type: Optional[DocumentType] = document_type
+        self.languages = languages
 
         self._libraries: OrderedDict[str, LibraryEntry] = OrderedDict()
         self._libraries_matchers: Optional[Dict[KeywordMatcher, LibraryEntry]] = None
@@ -689,7 +693,8 @@ class Namespace:
     async def get_libraries_matchers(self) -> Dict[KeywordMatcher, LibraryEntry]:
         if self._libraries_matchers is None:
             self._libraries_matchers = {
-                KeywordMatcher(v.alias or v.name or v.import_name): v for v in (await self.get_libraries()).values()
+                KeywordMatcher(v.alias or v.name or v.import_name, False): v
+                for v in (await self.get_libraries()).values()
             }
         return self._libraries_matchers
 
@@ -701,7 +706,8 @@ class Namespace:
     async def get_resources_matchers(self) -> Dict[KeywordMatcher, ResourceEntry]:
         if self._resources_matchers is None:
             self._resources_matchers = {
-                KeywordMatcher(v.alias or v.name or v.import_name): v for v in (await self.get_resources()).values()
+                KeywordMatcher(v.alias or v.name or v.import_name, False): v
+                for v in (await self.get_resources()).values()
             }
         return self._resources_matchers
 
@@ -1528,11 +1534,11 @@ class Namespace:
         return self._finder
 
     @_logger.call(condition=lambda self, name: self._finder is not None and name not in self._finder._cache)
-    async def find_keyword(self, name: Optional[str]) -> Optional[KeywordDoc]:
+    async def find_keyword(self, name: Optional[str], raise_keyword_error: bool = True) -> Optional[KeywordDoc]:
         if self._finder is not None:
-            return await self._finder.find_keyword(name)
+            return await self._finder.find_keyword(name, raise_keyword_error)
 
-        return await (await self.get_finder()).find_keyword(name)
+        return await (await self.get_finder()).find_keyword(name, raise_keyword_error)
 
 
 class DiagnosticsEntry(NamedTuple):
@@ -1556,7 +1562,7 @@ class KeywordFinder:
     def reset_diagnostics(self) -> None:
         self.diagnostics = []
 
-    async def find_keyword(self, name: Optional[str]) -> Optional[KeywordDoc]:
+    async def find_keyword(self, name: Optional[str], raise_keyword_error: bool = False) -> Optional[KeywordDoc]:
         try:
             self.reset_diagnostics()
 
@@ -1566,13 +1572,21 @@ class KeywordFinder:
                 self.diagnostics = cached[1]
                 return cached[0]
             else:
-                result = await self._find_keyword(name)
-                if result is None:
-                    self.diagnostics.append(
-                        DiagnosticsEntry(
-                            f"No keyword with name {repr(name)} found.", DiagnosticSeverity.ERROR, "KeywordError"
+                try:
+                    result = await self._find_keyword(name)
+                    if result is None:
+                        self.diagnostics.append(
+                            DiagnosticsEntry(
+                                f"No keyword with name {repr(name)} found.", DiagnosticSeverity.ERROR, "KeywordError"
+                            )
                         )
-                    )
+                except KeywordError as e:
+                    if raise_keyword_error:
+                        raise
+
+                    result = None
+                    self.diagnostics.append(DiagnosticsEntry(str(e), DiagnosticSeverity.ERROR, "KeywordError"))
+
                 self._cache[name] = (result, self.diagnostics)
 
                 return result
@@ -1759,9 +1773,22 @@ class KeywordFinder:
         )
 
     async def _get_bdd_style_keyword(self, name: str) -> Optional[KeywordDoc]:
-        lower = name.lower()
-        for prefix in ["given ", "when ", "then ", "and ", "but "]:
-            if lower.startswith(prefix):
-                return await self._find_keyword(name[len(prefix) :])  # noqa: E203
+        if get_robot_version() < (5, 1):
+            lower = name.lower()
+            for prefix in ["given ", "when ", "then ", "and ", "but "]:
+                if lower.startswith(prefix):
+                    return await self._find_keyword(name[len(prefix) :])  # noqa: E203
+            return None
 
-        return None
+        else:
+            parts = name.split(maxsplit=1)
+            if len(parts) < 2:
+                return None
+            prefix, keyword = parts
+            if prefix.title() in (
+                self.namespace.languages.bdd_prefixes
+                if self.namespace.languages is not None
+                else {"Given ", "When ", "Then ", "And ", "But "}
+            ):
+                return await self._find_keyword(keyword)
+            return None
