@@ -135,11 +135,9 @@ class DiscoveringProtocolPart(RobotLanguageServerProtocolPart):
 
         def get_document_text(source: str) -> str:
             if self.parent._loop:
-                doc = asyncio.run_coroutine_threadsafe(
-                    self.parent.documents.get(Uri.from_path(source).normalized()), self.parent._loop
-                ).result()
+                doc = self.parent.documents.get_sync(Uri.from_path(source).normalized())
                 if doc is not None and doc.opened_in_editor:
-                    return asyncio.run_coroutine_threadsafe(doc.text(), self.parent._loop).result()
+                    return doc.text_sync()
 
             return source
 
@@ -296,7 +294,7 @@ class DiscoveringProtocolPart(RobotLanguageServerProtocolPart):
             try:
                 config = await self.get_config(workspace_folder)
                 rpa_mode = config.get_rpa_mode() if config is not None else None
-                languages = config.languages if config is not None else None
+                languages = await self.parent.documents_cache.get_workspace_languages(workspace_folder)
 
                 if paths is None and config is not None:
                     paths = config.paths
@@ -342,7 +340,7 @@ class DiscoveringProtocolPart(RobotLanguageServerProtocolPart):
                     return [
                         TestItem(
                             type="workspace",
-                            id=str(Path.cwd()),
+                            id=str(Path.cwd().resolve()),
                             label=Path.cwd().name,
                             longname=Path.cwd().name,
                             uri=str(Uri.from_path(Path.cwd())),
@@ -375,7 +373,7 @@ class DiscoveringProtocolPart(RobotLanguageServerProtocolPart):
                 return [
                     TestItem(
                         type="error",
-                        id=str(Uri.from_path(Path.cwd())),
+                        id=str(Uri.from_path(Path.cwd().resolve())),
                         longname="error",
                         label=Path.cwd().name,
                         error=str(e),
