@@ -291,7 +291,7 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
         if result is not None:
             keyword_doc, keyword_token = result
 
-            keyword_token = self.strip_bdd_prefix(keyword_token)
+            keyword_token = self.strip_bdd_prefix(namespace, keyword_token)
 
             lib_entry, kw_namespace = await self.get_namespace_info_from_keyword(namespace, keyword_token)
 
@@ -362,7 +362,7 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
         if result is not None:
             keyword_doc, keyword_token = result
 
-            keyword_token = self.strip_bdd_prefix(keyword_token)
+            keyword_token = self.strip_bdd_prefix(namespace, keyword_token)
 
             lib_entry, kw_namespace = await self.get_namespace_info_from_keyword(namespace, keyword_token)
 
@@ -424,12 +424,13 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
             if keyword_token is None or keyword_token.value is None or keyword_token.value.upper() in ("", "NONE"):
                 return None
 
-            keyword_token = self.strip_bdd_prefix(keyword_token)
+            namespace = await self.parent.documents_cache.get_namespace(document)
+            if namespace is None:
+                return None
+
+            keyword_token = self.strip_bdd_prefix(namespace, keyword_token)
 
             if position.is_in_range(range_from_token(keyword_token)):
-                namespace = await self.parent.documents_cache.get_namespace(document)
-                if namespace is None:
-                    return None
 
                 keyword_doc = await namespace.find_keyword(template_node.value)
                 if keyword_doc is not None:
