@@ -266,7 +266,7 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
         if result is not None:
             keyword_doc, keyword_token = result
 
-            keyword_token = self.strip_bdd_prefix(keyword_token)
+            keyword_token = self.strip_bdd_prefix(namespace, keyword_token)
 
             lib_entry, kw_namespace = await self.get_namespace_info_from_keyword(namespace, keyword_token)
 
@@ -316,7 +316,7 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
         if result is not None:
             keyword_doc, keyword_token = result
 
-            keyword_token = self.strip_bdd_prefix(keyword_token)
+            keyword_token = self.strip_bdd_prefix(namespace, keyword_token)
 
             lib_entry, kw_namespace = await self.get_namespace_info_from_keyword(namespace, keyword_token)
 
@@ -352,13 +352,13 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
             if keyword_token is None:
                 return None
 
-            keyword_token = self.strip_bdd_prefix(keyword_token)
+            namespace = await self.parent.documents_cache.get_namespace(document)
+            if namespace is None:
+                return None
+
+            keyword_token = self.strip_bdd_prefix(namespace, keyword_token)
 
             if position.is_in_range(range_from_token(keyword_token)):
-                namespace = await self.parent.documents_cache.get_namespace(document)
-                if namespace is None:
-                    return None
-
                 keyword_doc = await namespace.find_keyword(template_node.value)
 
                 if keyword_doc is not None:
